# API Reference

Complete API reference for Sklearn-Optuna.

## OptunaSearchCV

::: sklearn_optuna.search.OptunaSearchCV
    options:
      show_root_heading: true
      show_source: true
      show_bases: true
      inherited_members: true
      filters:
        - "!^_"
      show_if_no_docstring: false

## Sampler

::: sklearn_optuna.optuna.Sampler
    options:
      show_root_heading: true
      show_source: true
      show_bases: true
      inherited_members: true
      filters:
        - "!^_"
      show_if_no_docstring: false

## Storage

::: sklearn_optuna.optuna.Storage
    options:
      show_root_heading: true
      show_source: true
      show_bases: true
      inherited_members: true
      filters:
        - "!^_"
      show_if_no_docstring: false

## Callback

::: sklearn_optuna.optuna.Callback
    options:
      show_root_heading: true
      show_source: true
      show_bases: true
      inherited_members: true
      filters:
        - "!^_"
      show_if_no_docstring: false
